Logo Euclid.BVH

BvhPair Type

A result of a closest pair search in a Bvh tree. Holds the indices of the two items (into the input array) and the distance between them.

Record fields

Record Field Description

Distance

Full Usage: Distance

Field type: float

The distance between the two items.

Field type: float

IdxA

Full Usage: IdxA

Field type: int

The index of the first item in the input array of the Bvh.

Field type: int

IdxB

Full Usage: IdxB

Field type: int

The index of the second item in the input array of the Bvh.

Field type: int

Type something to start searching.