LinePair Type
A result of a closest pair search in a LineBvh. Holds the indices of the two lines (into the input array) and the distance between them. An alias for BvhPair.
A result of a closest pair search in a LineBvh. Holds the indices of the two lines (into the input array) and the distance between them. An alias for BvhPair.