LineBvh2d Type
A static Bounding Volume Hierarchy (BVH) over 2D lines built from Euclid bounding rectangles (BRect).
Instance members
| Instance member |
Description
|
|
Finds all pairs of lines closer than the given maximum distance.
|
|
Finds the closest line in the tree to the given 2D point.
|
|
Finds the closest line in the tree to the given query line.
|
|
Finds the pair of closest lines among all lines in the tree.
|
|
|
Full Usage:
this.Count
Returns: int
|
The count of lines in this LineBvh2d.
|
|
|
|
Finds all lines whose bounding rectangle is within tolerance of the given rectangle.
|
|
Finds all lines whose bounding rectangle is within tolerance of the given point.
|
|
For every line in the tree finds its nearest neighbor line.
|
|
The axis aligned bounding rectangle around all lines in this LineBvh2d.
|
Static members
| Static member |
Description
|
Full Usage:
LineBvh2d.DefaultLeafSize
Returns: int
|
|
|
Euclid.BVH